@@ -349,7 +349,8 @@ class GraphqlWsConsumer(ch_websocket.AsyncJsonWebsocketConsumer):
         else:
             error_msg = f"Message of unknown type '{msg_type}' received!"
             task = self._send_gql_error(
-                content["id"] if "id" in content else -1, error_msg,
+                content["id"] if "id" in content else -1,
+                error_msg,
             )
             LOG.warning("GraphQL WS Client error: %s", error_msg)
 
@@ -549,6 +550,12 @@ class GraphqlWsConsumer(ch_websocket.AsyncJsonWebsocketConsumer):
             # from the dict-like one provided by the Channels.
             context = ScopeAsContext(self.scope)
 
+            # Adding channel name to the context because it seems to be
+            # useful for some use cases, take a loot at the issue from
+            # more details:
+            # https://github.com/datadvance/DjangoChannelsGraphqlWs/issues/41#issuecomment-663951595
+            context["channel_name"] = self.channel_name
+
             # The `register` will be called from the worker thread
             # (spawned for a GraphQL processing) when a client
             # subscribes. So we "synchronize" it with `async_to_sync`.
@@ -569,7 +576,7 @@ class GraphqlWsConsumer(ch_websocket.AsyncJsonWebsocketConsumer):
                 """
 
                 # Avoid circular imports with local import.
-                # pylint: disable=import-outside-toplevel
+                # pylint: disable=import-outside-toplevel,cyclic-import
                 from .subscription import Subscription
 
                 # We do not expose `Subscription._subscribe` because
